@@ -157,6 +157,23 @@ def _repeat(target, counts):
 
 @nb.jit(nopython=True, inline="always")
 def bounded_uint(ub):
+    """Produces an unbiased random integer within the half-open set of 0 to ub.
+
+    Based on Daniel Lemire's implementation.
+
+    Notes
+    -----
+    https://lemire.me/blog/2019/06/06/nearly-divisionless-random-integer-generation-on-various-systems/
+
+    Parameters
+    ----------
+    ub : int
+        The upper bound plus one.
+
+    Returns
+    -------
+    int
+    """    
     x = np.random.randint(low=2 ** 32)
     m = ub * x
     l = np.uint32(m)
@@ -175,6 +192,8 @@ def bounded_uint(ub):
 
 @nb.jit(nopython=True, cache=True)
 def nb_fast_shuffle(arr):
+    """Reimplementation of Fisher-Yates shuffle using bounded_uint to generate random numbers.
+    """    
     i = arr.shape[0] - 1
     while i > 0:
         j = bounded_uint(i + 1)
@@ -184,6 +203,15 @@ def nb_fast_shuffle(arr):
 
 @nb.jit(nopython=True, cache=True)
 def nb_strat_shuffle(arr, stratification):
+    """Stratified Fisher-Yates shuffle.
+
+    Parameters
+    ----------
+    arr : 1D array-like
+        Target array.
+    stratification : 1D array-like
+        Ranges to shuffle within. Must be sorted.
+    """    
     for v, w in zip(stratification[:-1], stratification[1:]):
         i = w - v - 1
         while i > 0:
@@ -564,42 +592,3 @@ def class_make_ufunc_list(target, reference, counts):
     return ufunc_list
 
 
-@nb.jit(nopython=True, cache=True)
-def _compute_interval(null, null_data, target_data, treatment_col, interval):
-    lower_bound = (100 - interval) / 200
-    upper_bound = 1 - lower_bound
-
-    x = null_data[:, treatment_col]
-    y = null_data[:, -1]
-
-    denom = _cov_std_error(x, y)
-    lower = np.quantile(null, lower_bound) * denom / bivar_central_moment(x, x)
-    upper = np.quantile(null, upper_bound) * denom / bivar_central_moment(x, x)
-
-    x = target_data[:, treatment_col]
-    y = target_data[:, -1]
-    denom = _cov_std_error(x, y)
-
-    lower = lower + (bivar_central_moment(x, y) / bivar_central_moment(x, x))
-    upper = upper + (bivar_central_moment(x, y) / bivar_central_moment(x, x))
-    return (lower, upper)
-
-
-@nb.jit(nopython=True, cache=True)
-def _cov_std_error(x, y):
-    n = len(x)
-    # first term is the second symmetric bivariate central moment. an approximate
-    # bias correction of n - root(2) is applied
-    denom_1 = bivar_central_moment(x, y, pow=2, ddof=2 ** 0.5)
-
-    # second term is the product of the standard deviations of x and y over n - 1.
-    # this term rapidly goes to 0 as n goes to infinity
-    denom_2 = (
-        bivar_central_moment(x, x, pow=1, ddof=1)
-        * bivar_central_moment(y, y, pow=1, ddof=1)
-    ) / (n - 1)
-
-    # third term is the square of the covariance of x and y. an approximate bias
-    # correction of n - root(3) is applied
-    denom_3 = ((n - 2) * (bivar_central_moment(x, y, pow=1, ddof=1.75) ** 2)) / (n - 1)
-    return ((1 / (n - 1.5)) * (denom_1 + denom_2 - denom_3)) ** 0.5
