@@ -1,6 +1,7 @@
 import numpy as np
 from itertools import cycle
 from numba import jit
+from functools import lru_cache
 from hierarch.internal_functions import (
     nb_reweighter,
     nb_reweighter_real,
@@ -450,15 +451,19 @@ class Permuter:
             try:
                 values[:, -3]
                 keys = nb_unique(values[:, :-2])[1]
-                keys = np.append(keys, data.shape[0])
+                keys = np.append(keys, values[:, -3].shape[0])
             except IndexError:
-                keys = np.empty(0, dtype=np.int64)
+                keys = np.zeros(1, dtype=np.int64)
+                keys = np.append(keys, values[:, -2].shape[0])
+            keys = tuple(keys.tolist())
 
             if indexes.size == len(data):
                 self.transform = self._random_return(col_to_permute, keys)
 
             else:
                 col_values = data[:, col_to_permute][indexes]
+                col_values = tuple(col_values.tolist())
+                counts = tuple(counts.tolist())
                 self.transform = self._random_repeat_return(
                     col_to_permute, col_values, keys, counts
                 )
@@ -505,36 +510,51 @@ class Permuter:
         return _rep_iter_return_impl
 
     @staticmethod
+    @lru_cache()
     def _random_return(col_to_permute, keys):
         """Transformer when exact is False and repetition is not required.
         """
 
-        @jit(nopython=True, cache=True)
-        def _random_return_impl(data):
-            if col_to_permute == 0:
+        if col_to_permute == 0:
+
+            @jit(nopython=True)
+            def _random_return_impl(data):
                 nb_fast_shuffle(data[:, col_to_permute])
-            else:
+                return data
+
+        else:
+
+            @jit(nopython=True)
+            def _random_return_impl(data):
                 nb_strat_shuffle(data[:, col_to_permute], keys)
-            return data
+                return data
 
         return _random_return_impl
 
     @staticmethod
+    @lru_cache()
     def _random_repeat_return(col_to_permute, col_values, keys, counts):
         """Transformer when exact is False and repetition is required.
         """
+        col_values = np.array(col_values)
+        counts = np.array(counts)
+        if col_to_permute == 0:
 
-        @jit(nopython=True, cache=True)
-        def _random__repeat_return_impl(data):
-            shuffled_col_values = col_values.copy()
-            if col_to_permute == 0:
+            @jit(nopython=True)
+            def _random_repeat_return_impl(data):
+                shuffled_col_values = col_values.copy()
                 nb_fast_shuffle(shuffled_col_values)
-            else:
+                data[:, col_to_permute] = np.repeat(shuffled_col_values, counts)
+                return data
+
+        else:
+
+            @jit(nopython=True)
+            def _random_repeat_return_impl(data):
+                shuffled_col_values = col_values.copy()
                 nb_strat_shuffle(shuffled_col_values, keys)
+                data[:, col_to_permute] = np.repeat(shuffled_col_values, counts)
+                return data
 
-            shuffled_col_values = np.repeat(shuffled_col_values, counts)
-            data[:, col_to_permute] = shuffled_col_values
-            return data
-
-        return _random__repeat_return_impl
+        return _random_repeat_return_impl
 
